package eu.kanade.tachiyomi.multisrc.madara

import generator.ThemeSourceData.MultiLang
import generator.ThemeSourceData.SingleLang
import generator.ThemeSourceGenerator

class MadaraGenerator : ThemeSourceGenerator {

    override val themePkg = "madara"

    override val themeClass = "Madara"

    override val baseVersionCode: Int = 33

    override val sources = listOf(
        MultiLang("MangaForFree.net", "https://mangaforfree.net", listOf("en", "ko", "all"), isNsfw = true, className = "MangaForFreeFactory", pkgName = "mangaforfree", overrideVersionCode = 1),
        MultiLang("Manhwa18.cc", "https://manhwa18.cc", listOf("en", "ko", "all"), isNsfw = true, className = "Manhwa18CcFactory", pkgName = "manhwa18cc", overrideVersionCode = 4),
        SingleLang("1st Kiss-Manga (unoriginal)", "https://1stkiss-manga.com", "en", className = "FirstKissDashManga"),
        SingleLang("1st Manhwa", "https://1stmanhwa.com", "en", isNsfw = true, className = "FirstManhwa"),
        SingleLang("1stKissManga.tv", "https://1stkissmanga.tv", "en", isNsfw = true, className = "FirstKissMangaTv"),
        SingleLang("247Manga", "https://247manga.com", "en", className = "Manga247", overrideVersionCode = 1),
        SingleLang("Adonis Fansub", "https://manga.adonisfansub.com", "tr", overrideVersionCode = 1),
        SingleLang("Adult Webtoon", "https://adultwebtoon.com", "en", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Akimangá", "https://akimanga.com", "pt-BR", isNsfw = true, className = "Akimanga"),
        SingleLang("AllPornComic", "https://allporncomic.com", "en", isNsfw = true),
        SingleLang("Amuy", "https://apenasmaisumyaoi.com", "pt-BR", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Anikiga", "https://anikiga.com", "tr"),
        SingleLang("Anisa Manga", "https://anisamanga.com", "tr"),
        SingleLang("Ansh Scans", "https://anshscans.org", "en", overrideVersionCode = 1),
        SingleLang("ApollComics", "https://apollcomics.xyz", "es", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Apolltoons", "https://apolltoons.xyz", "es", isNsfw = true),
        SingleLang("Armoni Scans", "https://armoniscans.net", "tr"),
        SingleLang("Aqua Manga", "https://aquamanga.org", "en", overrideVersionCode = 8),
        SingleLang("AQUA Scans", "https://aquascans.com", "en", className = "ManhwaWorld", overrideVersionCode = 1),
        SingleLang("ArazNovel", "https://www.araznovel.com", "tr", overrideVersionCode = 3),
        SingleLang("Arcanescans", "https://arcanescans.com", "en"),
        SingleLang("Arthur Scan", "https://arthurscan.xyz", "pt-BR", overrideVersionCode = 4),
        SingleLang("Astral-Manga", "https://astral-manga.fr", "fr", className = "AstralManga"),
        SingleLang("Astrum Scans", "https://astrumscans.xyz", "pt-BR", isNsfw = true),
        SingleLang("Asura Scans.us (unoriginal)", "https://asurascans.us", "en", className = "AsuraScansUs"),
        SingleLang("Atlantis Scan", "https://scansatlanticos.com", "es", isNsfw = true),
        SingleLang("Azora", "https://azoramoon.com", "ar", overrideVersionCode = 7),
        SingleLang("Babel Wuxia", "https://babelwuxia.com", "en", overrideVersionCode = 1),
        SingleLang("Baka Manhua", "https://bakamh.com", "zh", isNsfw = true, className = "Bakamh", sourceName = "巴卡漫画"),
        SingleLang("Bakaman", "https://bakaman.net", "th", overrideVersionCode = 1),
        SingleLang("Banana Manga", "https://bananamanga.net", "en", isNsfw = true),
        SingleLang("BarManga", "https://barmanga.com", "es"),
        SingleLang("BestManga", "https://bestmanga.club", "ru", overrideVersionCode = 1),
        SingleLang("BestManhua", "https://bestmanhua.com", "en", overrideVersionCode = 2),
        SingleLang("BirdToon", "https://birdtoon.net", "id", isNsfw = true),
        SingleLang("BokugenTranslation", "https://bokugents.com", "es", overrideVersionCode = 1),
        SingleLang("Boruto Explorer", "https://leitor.borutoexplorer.com.br", "pt-BR", overrideVersionCode = 1),
        SingleLang("BoysLove", "https://boyslove.me", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Burning Scans", "https://burningscans.com", "pt-BR", isNsfw = true),
        SingleLang("Café com Yaoi", "http://cafecomyaoi.com.br", "pt-BR", className = "CafeComYaoi", isNsfw = true, overrideVersionCode = 1),
        SingleLang("CAT-translator", "https://cats-translator.com/manga", "th", className = "CatTranslator", overrideVersionCode = 2),
        SingleLang("Cat300", "https://cat300.com", "th", isNsfw = true, overrideVersionCode = 1),
        SingleLang("CBHentai", "https://cbhentai.net", "vi", isNsfw = true, overrideVersionCode = 7, pkgName = "hentaicube", className = "HentaiCB"),
        SingleLang("Cerise Scan", "https://cerisescan.net", "pt-BR", pkgName = "cerisescans", isNsfw = true, overrideVersionCode = 8),
        SingleLang("Clover Manga", "https://clover-manga.com", "tr", overrideVersionCode = 2),
        SingleLang("Coco Rip", "https://cocorip.net", "es"),
        SingleLang("Coffee Manga", "https://coffeemanga.io", "en", overrideVersionCode = 2),
        SingleLang("Colored Manga", "https://coloredmanga.com", "en", overrideVersionCode = 2),
        SingleLang("Comic Scans", "https://www.comicscans.org", "en"),
        SingleLang("Comics Valley", "https://comicsvalley.com", "hi", isNsfw = true, overrideVersionCode = 1),
        SingleLang("ComicsWorld", "https://comicsworld.in", "hi"),
        SingleLang("Comicz.net v2", "https://v2.comiz.net", "all", isNsfw = true, className = "ComiczNetV2"),
        SingleLang("Cookie Kiara", "https://18.kiara.cool", "en", isNsfw = true),
        SingleLang("CopyPasteScan", "https://copypastescan.xyz", "es", overrideVersionCode = 1),
        SingleLang("CreepyScans", "https://creepyscans.com", "en"),
        SingleLang("DapRob", "https://daprob.com", "es"),
        SingleLang("Dark Scans", "https://darkscans.com", "en", overrideVersionCode = 1),
        SingleLang("Dark-scan", "https://dark-scan.com", "en", isNsfw = true, className = "DarkScan"),
        SingleLang("Decadence Scans", "https://reader.decadencescans.com", "en", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Demon Sect", "https://demonsect.com.br", "pt-BR", pkgName = "prismascans", overrideVersionCode = 4),
        SingleLang("Dessert Scan", "https://cabaredowatame.site", "pt-BR", isNsfw = true),
        SingleLang("DiamondFansub", "https://diamondfansub.com", "tr", overrideVersionCode = 1),
        SingleLang("Doodmanga", "https://www.doodmanga.com", "th"),
        SingleLang("DoujinHentai", "https://doujinhentai.net", "es", isNsfw = true, overrideVersionCode = 1),
        SingleLang("DragonTea", "https://dragontea.ink", "en", overrideVersionCode = 3),
        SingleLang("DragonTranslation.net", "https://dragontranslation.net", "es", isNsfw = true, className = "DragonTranslationNet"),
        SingleLang("Drake Scans", "https://drakescans.com", "en", overrideVersionCode = 4),
        SingleLang("Drope Scan", "https://dropescan.com", "pt-BR", overrideVersionCode = 4),
        SingleLang("Elite Manga", "https://www.elitemanga.org", "en"),
        SingleLang("Emperor Scan", "https://emperorscan.com", "es", overrideVersionCode = 1),
        SingleLang("Empire Webtoon", "https://webtoonsempireron.com", "ar", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Eromiau", "https://www.eromiau.com", "es", isNsfw = true),
        SingleLang("Esomanga", "https://esomanga.com", "tr", overrideVersionCode = 1),
        SingleLang("EZmanga", "https://ezmanga.net", "en"),
        SingleLang("FactManga", "https://factmanga.com", "en"),
        SingleLang("Fay Scans", "https://fayscans.net", "pt-BR", overrideVersionCode = 2),
        SingleLang("Fire Scans", "https://firescans.xyz", "en", overrideVersionCode = 1),
        SingleLang("Fleur Blanche", "https://fbsquads.com", "pt-BR", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Flower Manga", "https://flowermanga.com", "pt-BR"),
        SingleLang("Fox White", "https://foxwhite.com.br", "pt-BR"),
        SingleLang("FR-Scan", "https://fr-scan.com", "fr", pkgName = "frdashscan", className = "FRScan", overrideVersionCode = 5),
        SingleLang("Free Manga", "https://freemanga.me", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Free Manhwa", "https://manhwas.com", "en"),
        SingleLang("FreeMangaTop", "https://freemangatop.com", "en", overrideVersionCode = 2),
        SingleLang("FreeWebtoonCoins", "https://freewebtooncoins.com", "en", overrideVersionCode = 1),
        SingleLang("GalaxyDegenScans", "https://gdscans.com", "en", overrideVersionCode = 4),
        SingleLang("Gatemanga", "https://gatemanga.com", "ar", overrideVersionCode = 1),
        SingleLang("Gekkou Scans", "https://gekkou.site", "pt-BR", isNsfw = true, pkgName = "gekkouscan", overrideVersionCode = 2),
        SingleLang("Ghost Scan", "https://ghostscan.com.br", "pt-BR", isNsfw = true),
        SingleLang("Girls Love Manga!", "https://glmanga.com", "en", isNsfw = true, className = "GirlsLoveManga"),
        SingleLang("Global Bloging", "https://globalbloging.com", "en"),
        SingleLang("Glory Manga", "https://glorymanga.com", "tr"),
        SingleLang("Good Girls Scan", "https://goodgirls.moe", "en", isNsfw = true),
        SingleLang("Goof Fansub", "https://gooffansub.com", "pt-BR", isNsfw = true),
        SingleLang("Gourmet Scans", "https://gourmetsupremacy.com", "en", isNsfw = true),
        SingleLang("Grabber Zone", "https://grabber.zone", "all"),
        SingleLang("Gri Melek", "https://grimelek.net", "tr", isNsfw = true, className = "Siyahmelek", overrideVersionCode = 4),
        SingleLang("GuncelManga", "https://guncelmanga.com", "tr", overrideVersionCode = 1),
        SingleLang("Hades no Fansub Hentai", "https://h.mangareaderpro.com", "es", isNsfw = true),
        SingleLang("Hades no Fansub", "https://hadesnofansub.com", "es", isNsfw = true, overrideVersionCode = 2, className = "HadesNoFansub"),
        SingleLang("Harimanga", "https://harimanga.com", "en", overrideVersionCode = 3),
        SingleLang("Hattori Manga", "https://hattorimanga.com", "tr", isNsfw = true),
        SingleLang("Hayalistic", "https://hayalistic.com", "tr"),
        SingleLang("Hentai Manga", "https://hentaimanga.me", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Hentai Teca", "https://hentaiteca.net", "pt-BR", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Hentai-Scantrad", "https://hentai.scantrad-vf.cc", "fr", isNsfw = true, className = "HentaiScantrad", overrideVersionCode = 1),
        SingleLang("Hentai20", "https://hentai20.io", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Hentai3z", "https://hentai3z.xyz", "en", isNsfw = true),
        SingleLang("Hentai4Free", "https://hentai4free.net", "en", isNsfw = true),
        SingleLang("HentaiRead", "https://hentairead.com", "en", isNsfw = true, className = "Hentairead", overrideVersionCode = 3),
        SingleLang("HentaiWebtoon", "https://hentaiwebtoon.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("HentaiXComic", "https://hentaixcomic.com", "en", isNsfw = true),
        SingleLang("HentaiXDickgirl", "https://hentaixdickgirl.com", "en", isNsfw = true),
        SingleLang("HentaiXYuri", "https://hentaixyuri.com", "en", isNsfw = true),
        SingleLang("HentaiZM", "https://manga.hentaizm.fun", "tr", isNsfw = true),
        SingleLang("HentaiZone", "https://hentaizone.xyz", "fr", isNsfw = true, overrideVersionCode = 1),
        SingleLang("HerenScan", "https://herenscan.com", "es"),
        SingleLang("HipercooL", "https://hiper.cool", "pt-BR", isNsfw = true, className = "Hipercool", overrideVersionCode = 1),
        SingleLang("Hiperdex", "https://hiperdex.com", "en", isNsfw = true, overrideVersionCode = 11),
        SingleLang("HistoireDHentai", "https://hhentai.fr", "fr", isNsfw = true),
        SingleLang("Hizomanga", "https://hizomanga.com", "ar", overrideVersionCode = 1),
        SingleLang("HM2D", "https://mangadistrict.com/hdoujin", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("HouseMangas", "https://housemangas.com", "es"),
        SingleLang("Hreads", "https://hreads.net", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Hunters Scans", "https://huntersscan.xyz", "pt-BR", isNsfw = true),
        SingleLang("I Love Manhwa", "https://ilovemanhwa.com", "en", isNsfw = true),
        SingleLang("Illusion Scan", "https://illusionscan.com", "pt-BR", isNsfw = true),
        SingleLang("Immortal Updates", "https://immortalupdates.com", "en", overrideVersionCode = 6),
        SingleLang("InfraFandub", "https://infrafandub.com", "es", overrideVersionCode = 1),
        SingleLang("Inmortal Scan", "https://manga.mundodrama.site", "es"),
        SingleLang("InstaManhwa", "https://www.instamanhwa.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("IsekaiScan.to (unoriginal)", "https://m.isekaiscan.to", "en", isNsfw = true, pkgName = "isekaiscaneu", className = "IsekaiScanTo", overrideVersionCode = 3),
        SingleLang("IsekaiScan.top (unoriginal)", "https://isekaiscan.top", "en", className = "IsekaiScanTop", overrideVersionCode = 1),
        SingleLang("IsekaiScanManga (unoriginal)", "https://isekaiscanmanga.com", "en", className = "IsekaiScanManga", overrideVersionCode = 1),
        SingleLang("Its Your Right Manhua", "https://itsyourightmanhua.com", "en", overrideVersionCode = 2),
        SingleLang("Jiangzaitoon", "https://jiangzaitoon.cc", "tr", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Jimanga", "https://jimanga.com", "en"),
        SingleLang("Kakusei Project", "https://kakuseiproject.com.br", "pt-BR"),
        SingleLang("Kami Sama Explorer", "https://leitor.kamisama.com.br", "pt-BR", overrideVersionCode = 2),
        SingleLang("Karatcam Scans", "https://karatcam-scans.fr", "fr", isNsfw = true),
        SingleLang("Kataitake", "https://www.kataitake.fr", "fr", isNsfw = true),
        SingleLang("KenhuaScan", "https://kenhuav2scan.com", "es"),
        SingleLang("Kings-Manga", "https://www.kings-manga.co", "th", className = "KingsManga"),
        SingleLang("Kissmanga.in", "https://kissmanga.in", "en", className = "KissmangaIn", overrideVersionCode = 3),
        SingleLang("KlikManga", "https://klikmanga.id", "id", overrideVersionCode = 2),
        SingleLang("Knight No Scanlation", "https://knightnoscanlation.com", "es", isNsfw = true),
        SingleLang("Koinobori Scan", "https://koinoboriscan.com", "es", isNsfw = true),
        SingleLang("Komik Chan", "https://komikchan.com", "en", overrideVersionCode = 1),
        SingleLang("Komik Gue", "https://komikgue.pro", "id", isNsfw = true),
        SingleLang("KSGroupScans", "https://ksgroupscans.com", "en"),
        SingleLang("Kun Manga", "https://kunmanga.com", "en", overrideVersionCode = 1),
        SingleLang("Lady Manga", "https://ladymanga.com", "en"),
        SingleLang("Lala Manga", "https://lalamanga.com", "en", isNsfw = true),
        SingleLang("Last Knight Translation", "https://lkscanlation.com", "es", isNsfw = true, className = "LKScanlation"),
        SingleLang("Lector Online", "https://lectorunm.life", "es", isNsfw = true, className = "Ikifeng", overrideVersionCode = 1),
        SingleLang("LectorManga.lat", "https://www.lectormanga.lat", "es", isNsfw = true, className = "LectorMangaLat"),
        SingleLang("Ler Yaoi", "https://leryaoi.com", "pt-BR", isNsfw = true),
        SingleLang("Leviatan Scans", "https://lscomic.com", "en", overrideVersionCode = 15),
        SingleLang("LHTranslation", "https://lhtranslation.net", "en", overrideVersionCode = 1),
        SingleLang("Lily Manga", "https://lilymanga.net", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Limbo Scan", "https://limboscan.com.br", "pt-BR", isNsfw = true),
        SingleLang("Link Start Scan", "https://www.linkstartscan.xyz", "pt-BR", isNsfw = true),
        SingleLang("Lolicon", "https://lolicon.mobi", "en", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Luffy Manga", "https://luffymanga.com", "en"),
        SingleLang("Lura Toon", "https://luratoon.com", "pt-BR", overrideVersionCode = 7, pkgName = "randomscan", className = "LuraToon"),
        SingleLang("LuxManga", "https://luxmanga.net", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("MadaraDex", "https://madaradex.org", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Maid Scan", "https://maidscan.com.br", "pt-BR"),
        SingleLang("Manga 18h", "https://manga18h.com", "en", isNsfw = true),
        SingleLang("Manga 18x", "https://manga18x.net", "en", isNsfw = true),
        SingleLang("Manga Action", "https://mangaaction.com", "en", overrideVersionCode = 2),
        SingleLang("Manga Bee", "https://mangabee.net", "en", isNsfw = true),
        SingleLang("Manga Bin", "https://mangabin.com", "en", overrideVersionCode = 1),
        SingleLang("Manga Chill", "https://toonchill.com", "en", overrideVersionCode = 7),
        SingleLang("Manga Crab", "https://mangacrab3.com", "es", overrideVersionCode = 7),
        SingleLang("Manga District", "https://mangadistrict.com", "en", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Manga Diyari", "https://manga-diyari.com", "tr", overrideVersionCode = 2),
        SingleLang("Manga Galaxy", "https://mangagalaxy.me", "en", overrideVersionCode = 1),
        SingleLang("Manga Hentai", "https://mangahentai.me", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Manga Keyfi", "https://mangakeyfi.net", "tr"),
        SingleLang("Manga Kiss", "https://mangakiss.org", "en", overrideVersionCode = 1),
        SingleLang("Manga Kitsu", "https://mangakitsu.com", "en"),
        SingleLang("Manga Leveling", "https://mangaleveling.com", "en", overrideVersionCode = 1),
        SingleLang("Manga Mammy", "https://mangamammy.ru", "ru", isNsfw = true),
        SingleLang("Manga Mitsu", "https://mangamitsu.com", "en", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Manga Nerds", "https://manganerds.com", "en"),
        SingleLang("Manga One Love", "https://mangaonelove.site", "ru", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Manga Online Team", "https://mangaonlineteam.com", "en"),
        SingleLang("Manga Queen", "https://mangaqueen.net", "en"),
        SingleLang("Manga Queen.com", "https://mangaqueen.com", "en", isNsfw = true, className = "MangaQueenCom"),
        SingleLang("Manga Read", "https://mangaread.co", "en", overrideVersionCode = 1),
        SingleLang("Manga Rock Team", "https://mangarockteam.com", "en", overrideVersionCode = 1),
        SingleLang("Manga Rock.team (unoriginal)", "https://mangarock.team", "en", className = "MangaRockTeamUnoriginal"),
        SingleLang("Manga Rocky", "https://mangarocky.com", "en", overrideVersionCode = 1),
        SingleLang("Manga Rose", "https://mangarose.net", "ar"),
        SingleLang("Manga Starz", "https://mangastarz.org", "ar", overrideVersionCode = 5),
        SingleLang("Manga Too", "https://mangatoo.com", "en", overrideVersionCode = 1),
        SingleLang("Manga Tx.gg (unoriginal)", "https://mangatx.gg", "en", className = "MangaTxGg"),
        SingleLang("Manga Weebs", "https://mangaweebs.in", "en", overrideVersionCode = 8),
        SingleLang("Manga Şehri", "https://manga-sehri.com", "tr", className = "MangaSehri", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Manga-1001.com", "https://manga-1001.com", "en", className = "MangaDash1001Com"),
        SingleLang("Manga-fast.com", "https://manga-fast.com", "en", className = "Mangafastcom", overrideVersionCode = 3),
        SingleLang("Manga-Raw.info (unoriginal)", "https://manga-raw.info", "en", isNsfw = true, className = "MangaRawInfo"),
        SingleLang("Manga-Scantrad", "https://manga-scantrad.io", "fr", className = "MangaScantrad", overrideVersionCode = 3),
        SingleLang("Manga-TX", "https://manga-tx.com", "en", className = "Mangatxunoriginal"),
        SingleLang("Manga18fx", "https://manga18fx.com", "en", isNsfw = true, overrideVersionCode = 5),
        SingleLang("Manga1st.online", "https://manga1st.online", "en", className = "MangaFirstOnline", overrideVersionCode = 1),
        SingleLang("Manga347", "https://manga347.com", "en", overrideVersionCode = 3),
        SingleLang("Manga3S", "https://manga3s.com", "en", overrideVersionCode = 4),
        SingleLang("Manga68", "https://manga68.com", "en", overrideVersionCode = 1),
        SingleLang("MangaBob", "https://mangabob.com", "en", overrideVersionCode = 1),
        SingleLang("MangaClash", "https://mangaclash.com", "en", overrideVersionCode = 3),
        SingleLang("MangaClash.tv (unoriginal)", "https://mangaclash.tv", "en", isNsfw = true, className = "MangaClashTv"),
        SingleLang("MangaCrazy", "https://mangacrazy.net", "all", isNsfw = true),
        SingleLang("MangaCultivator", "https://mangacultivator.com", "en", overrideVersionCode = 2),
        SingleLang("MangaCV", "https://mangacv.com", "en", isNsfw = true),
        SingleLang("MangaDeemak", "https://mangadeemak.com", "th", overrideVersionCode = 2),
        SingleLang("MangaDino.top (unoriginal)", "https://mangadino.top", "en", isNsfw = true, className = "MangaDinoTop"),
        SingleLang("MangaEffect", "https://mangaeffect.com", "en", overrideVersionCode = 1),
        SingleLang("Mangaforfree.com", "https://mangaforfree.com", "en", isNsfw = true, className = "Mangaforfreecom", overrideVersionCode = 1),
        SingleLang("MangaFoxFull", "https://mangafoxfull.com", "en"),
        SingleLang("MangaFreak.online", "https://mangafreak.online", "en", className = "MangaFreakOnline"),
        SingleLang("MangaGG", "https://mangagg.com", "en", overrideVersionCode = 2),
        SingleLang("MangaGo Yaoi", "https://mangagoyaoi.com", "en", isNsfw = true),
        SingleLang("MangaHub.fr", "https://mangahub.fr", "fr", isNsfw = true, className = "MangaHubFr", overrideVersionCode = 2),
        SingleLang("Mangakik", "https://mangakik.org", "en", overrideVersionCode = 2),
        SingleLang("MangaKing", "https://mangaking.net", "en"),
        SingleLang("MangaKitsune", "https://mangakitsune.com", "en", isNsfw = true, overrideVersionCode = 4),
        SingleLang("MangaKomi", "https://mangakomi.io", "en", overrideVersionCode = 5),
        SingleLang("Mangaland", "https://mangaland.net", "es", isNsfw = true),
        SingleLang("MangaLionz", "https://mangalionz.org", "ar", overrideVersionCode = 2),
        SingleLang("MangaManiacs", "https://mangamaniacs.org", "en", isNsfw = true),
        SingleLang("Manganelo.biz", "https://manganelo.biz", "en", isNsfw = true, className = "ManganeloBiz"),
        SingleLang("Manganelo.website (unoriginal)", "https://manganelo.website", "en", isNsfw = true, className = "ManganeloWebsite"),
        SingleLang("MangaOnline.team (unoriginal)", "https://mangaonline.team", "en", className = "MangaOnlineTeamUnoriginal"),
        SingleLang("MangaOwl.blog (unoriginal)", "https://mangaowl.blog", "en", isNsfw = true, className = "MangaOwlBlog"),
        SingleLang("MangaOwl.io (unoriginal)", "https://mangaowl.io", "en", isNsfw = true, className = "MangaOwlIo"),
        SingleLang("MangaOwl.one (unoriginal)", "https://mangaowl.one", "en", isNsfw = true, className = "MangaOwlOne"),
        SingleLang("MangaOwl.us (unoriginal)", "https://mangaowl.us", "en", isNsfw = true, className = "MangaOwlUs"),
        SingleLang("MangaPT", "https://mangapt.com", "es", isNsfw = true),
        SingleLang("MangaPure", "https://mangapure.net", "en", isNsfw = true),
        SingleLang("MangaRabic", "https://mangarabic.com", "ar", overrideVersionCode = 2),
        SingleLang("MangaRead.org", "https://www.mangaread.org", "en", className = "MangaReadOrg", overrideVersionCode = 2),
        SingleLang("MangaRolls", "https://mangarolls.net", "en", overrideVersionCode = 1),
        SingleLang("MangaRosie", "https://mangarosie.in", "en", isNsfw = true),
        SingleLang("MangaRuby.com", "https://mangaruby.com", "en", isNsfw = true, className = "MangaRubyCom"),
        SingleLang("Mangaryu", "https://mangaryu.com", "en", isNsfw = true),
        SingleLang("Mangas No Sekai", "https://mangasnosekai.com", "es", overrideVersionCode = 3),
        SingleLang("Mangas Origines", "https://mangas-origines.xyz", "fr", isNsfw = true, overrideVersionCode = 4),
        SingleLang("Mangas-Origines.fr", "https://mangas-origines.fr", "fr", className = "MangasOriginesFr"),
        SingleLang("MangaSco", "https://manhwasco.net", "en", overrideVersionCode = 2),
        SingleLang("MangaSiro", "https://mangasiro.com", "en", isNsfw = true),
        SingleLang("MangaSpark", "https://mangaspark.org", "ar", overrideVersionCode = 4),
        SingleLang("MangaStic", "https://mangastic9.com", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Mangasushi", "https://mangasushi.org", "en", overrideVersionCode = 3),
        SingleLang("MangaTone", "https://mangatone.com", "en"),
        SingleLang("MangaTop.site", "https://mangatop.site", "all", isNsfw = true, className = "MangaTopSite"),
        SingleLang("MangaToRead", "https://mangatoread.com", "en"),
        SingleLang("MangaTyrant", "https://mangatyrant.com", "en"),
        SingleLang("MangaUpdates.top (unoriginal)", "https://mangaupdates.top", "en", isNsfw = true, className = "MangaUpdatesTop"),
        SingleLang("MangaUS", "https://mangaus.xyz", "en", overrideVersionCode = 2),
        SingleLang("MangaVisa", "https://mangavisa.com", "en", pkgName = "mangaboss", className = "MangaVisa", overrideVersionCode = 1),
        SingleLang("MangaX1", "https://mangax1.com", "en"),
        SingleLang("Mangaxico", "https://mangaxico.com", "es", isNsfw = true),
        SingleLang("MangaXP", "https://mangaxp.com", "en", overrideVersionCode = 1),
        SingleLang("MangaYami", "https://www.mangayami.club", "en", overrideVersionCode = 2),
        SingleLang("Mangá Nanquim", "https://mangananquim.com", "pt-BR", className = "MangaNanquim"),
        SingleLang("Manhastro", "https://manhastro.com", "pt-BR"),
        SingleLang("Manhatic", "https://manhatic.com", "ar", isNsfw = true),
        SingleLang("Manhua ES", "https://manhuaes.com", "en", overrideVersionCode = 6),
        SingleLang("Manhua Fenix", "https://visorfenix.com", "es", className = "ManhuaFenix", pkgName = "mangafenix", overrideVersionCode = 4),
        SingleLang("Manhua Kiss", "https://manhuakiss.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Manhua Mix", "https://manhuamix.com", "en", className = "Manhuasnet", overrideVersionCode = 3),
        SingleLang("Manhua Plus", "https://manhuaplus.com", "en", overrideVersionCode = 6),
        SingleLang("Manhua SY", "https://www.manhuasy.com", "en", overrideVersionCode = 2),
        SingleLang("Manhua Zonghe", "https://manhuazonghe.com", "en", isNsfw = true),
        SingleLang("ManhuaBox", "https://manhuabox.net", "en", overrideVersionCode = 2),
        SingleLang("ManhuaChill", "https://manhuachill.com", "en"),
        SingleLang("ManhuaDex", "https://manhuadex.com", "en"),
        SingleLang("ManhuaFast", "https://manhuafast.com", "en", overrideVersionCode = 3),
        SingleLang("ManhuaFast.net (unoriginal)", "https://manhuafast.net", "en", className = "ManhuaFastNet"),
        SingleLang("Manhuaga", "https://manhuaga.com", "en", overrideVersionCode = 2),
        SingleLang("ManhuaHot", "https://manhuahot.com", "en"),
        SingleLang("ManhuaManhwa", "https://manhuamanhwa.com", "en", isNsfw = true),
        SingleLang("ManhuaManhwa.online", "https://manhuamanhwa.online", "en", className = "ManhuaManhwaOnline"),
        SingleLang("ManhuaScan.info (unoriginal)", "https://manhuascan.info", "en", isNsfw = true, className = "ManhuaScanInfo"),
        SingleLang("ManhuaUS", "https://manhuaus.com", "en", overrideVersionCode = 5),
        SingleLang("ManhuaZone", "https://manhuazone.org", "en", overrideVersionCode = 1),
        SingleLang("Manhwa Raw", "https://manhwaraw.com", "ko", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Manhwa-Latino", "https://manhwa-latino.com", "es", isNsfw = true, className = "ManhwaLatino", overrideVersionCode = 7),
        SingleLang("Manhwa-raw", "https://manhwa-raw.com", "all", isNsfw = true, className = "ManhwaDashRaw", overrideVersionCode = 1),
        SingleLang("Manhwa18.app", "https://manhwa18.app", "en", isNsfw = true, className = "Manhwa18app"),
        SingleLang("Manhwa18.org", "https://manhwa18.org", "en", isNsfw = true, className = "Manhwa18Org", overrideVersionCode = 2),
        SingleLang("Manhwa2Read", "https://manhwa2read.com", "en"),
        SingleLang("Manhwa365", "https://manhwa365.com", "en", isNsfw = true),
        SingleLang("Manhwa68", "https://manhwa68.com", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("ManhwaBookShelf", "https://manhwabookshelf.com", "en"),
        SingleLang("ManhwaClan", "https://manhwaclan.com", "en"),
        SingleLang("Manhwafull", "https://manhwafull.com", "en", overrideVersionCode = 1),
        SingleLang("Manhwahentai.me", "https://manhwahentai.me", "en", className = "ManhwahentaiMe", isNsfw = true, overrideVersionCode = 3),
        SingleLang("ManhwaManhua", "https://manhwamanhua.com", "en", isNsfw = true),
        SingleLang("ManhwaNew", "https://manhwanew.com", "en", isNsfw = true),
        SingleLang("Manhwas Men", "https://manhwas.men", "en", isNsfw = true),
        SingleLang("Manhwatop", "https://manhwatop.com", "en", overrideVersionCode = 2),
        SingleLang("ManhwaZ", "https://manhwaz.com", "en", isNsfw = true),
        SingleLang("Manhwua.fans", "https://manhwua.fans", "en", isNsfw = true, className = "Manhwuafans"),
        SingleLang("Mantraz Scan", "https://mantrazscan.com", "es"),
        SingleLang("ManWe", "https://manwe.pro", "tr", className = "EvaScans", overrideVersionCode = 1),
        SingleLang("ManyComic", "https://manycomic.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("ManyToon", "https://manytoon.com", "en", isNsfw = true, overrideVersionCode = 5),
        SingleLang("ManyToon.me", "https://manytoon.me", "en", isNsfw = true, className = "ManyToonMe", overrideVersionCode = 5),
        SingleLang("ManyToonClub", "https://manytoon.club", "ko", isNsfw = true, overrideVersionCode = 2),
        SingleLang("MG Komik", "https://mgkomik.id", "id", overrideVersionCode = 12),
        SingleLang("MHScans", "https://mhscans.com", "es"),
        SingleLang("Midnight Mess Scans", "https://midnightmess.org", "en", isNsfw = true, overrideVersionCode = 6),
        SingleLang("MidnightManga", "http://midnightmanga.com", "es"),
        SingleLang("Milftoon", "https://milftoon.xxx", "en", isNsfw = true, overrideVersionCode = 2),
        SingleLang("MiniTwo Scan", "https://minitwoscan.com", "pt-BR"),
        SingleLang("MMScans", "https://mm-scans.org", "en", overrideVersionCode = 7),
        SingleLang("Momo no Hana Scan", "https://momonohanascan.com", "pt-BR", className = "MomoNoHanaScan", overrideVersionCode = 1),
        SingleLang("MonarcaManga", "https://monarcamanga.com", "es"),
        SingleLang("Moon Witch In Love", "https://moonwitchinlovescan.com", "pt-BR"),
        SingleLang("MoonLovers Scan", "https://moonloversscan.com.br", "pt-BR", isNsfw = true),
        SingleLang("Mortals Groove", "https://mortalsgroove.com", "en", overrideVersionCode = 1),
        SingleLang("MR Yaoi Fansub", "https://mrbenne.com", "pt-BR", isNsfw = true, className = "MrYaoiFansub", overrideVersionCode = 1),
        SingleLang("Muctau", "https://bibimanga.com", "en", isNsfw = true, overrideVersionCode = 4),
        SingleLang("MurimScan", "https://murimscan.run", "en", isNsfw = true),
        SingleLang("My Manhwa", "https://mymanhwa.net", "en"),
        SingleLang("Mystical Merries", "https://mysticalmerries.com", "en", overrideVersionCode = 2),
        SingleLang("NeatManga", "https://neatmanga.com", "en", overrideVersionCode = 2),
        SingleLang("NekoPost.co (unoriginal)", "https://www.nekopost.co", "th", className = "NekoPostCo"),
        SingleLang("NekoScan", "https://nekoscan.com", "en", overrideVersionCode = 2),
        SingleLang("Neroxus", "https://neroxus.com.br", "pt-BR", className = "ImperioScans", pkgName = "imperioscans", overrideVersionCode = 3),
        SingleLang("NewManhua", "https://newmanhua.com", "en", isNsfw = true),
        SingleLang("Nexo Scans", "https://nexoscans.com", "pt-BR", overrideVersionCode = 1),
        SingleLang("Night Comic", "https://www.nightcomic.com", "en", overrideVersionCode = 1),
        SingleLang("Niji Translations", "https://niji-translations.com", "ar", overrideVersionCode = 1),
        SingleLang("Nitro Manga", "https://nitromanga.com", "en", className = "NitroScans", overrideVersionCode = 1),
        SingleLang("Norte Rose Scan", "https://norterose.com.br", "pt-BR", isNsfw = true),
        SingleLang("No Index Scan", "https://noindexscan.com", "pt-BR", isNsfw = true),
        SingleLang("Noblesse Translations", "https://www.noblessev1.com", "es", overrideVersionCode = 2),
        SingleLang("Nocturne Summer", "https://nocsummer.com.br", "pt-BR", isNsfw = true),
        SingleLang("NovelCrow", "https://novelcrow.com", "en", isNsfw = true),
        SingleLang("NovelMic", "https://novelmic.com", "en", overrideVersionCode = 1),
        SingleLang("Novels Town", "https://novelstown.cyou", "ar"),
        SingleLang("Oh No Manga", "https://ohnomanga.com", "en", isNsfw = true),
        SingleLang("Olaoe", "https://olaoe.cyou", "ar"),
        SingleLang("OnlyManhwa", "https://onlymanhwa.org", "en", isNsfw = true),
        SingleLang("OPSCANS", "https://opchapters.com", "en"),
        SingleLang("Pantheon Scan", "https://pantheon-scan.com", "fr", overrideVersionCode = 1),
        SingleLang("Paragon Scans", "https://paragonscans.com", "en", isNsfw = true),
        SingleLang("Passa Mão Scan", "https://passamaoscan.com", "pt-BR", isNsfw = true, className = "PassaMaoScan"),
        SingleLang("Paw Manga", "https://pawmanga.com", "en", isNsfw = true),
        SingleLang("Petrotechsociety", "https://www.petrotechsociety.org", "en", isNsfw = true),
        SingleLang("Pian Manga", "https://pianmanga.me", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Pink Sea Unicorn", "https://psunicorn.com", "pt-BR", isNsfw = true),
        SingleLang("Pirulito Rosa", "https://pirulitorosa.site", "pt-BR", isNsfw = true),
        SingleLang("Platinum Crown", "https://platinumscans.com", "en", overrideVersionCode = 1),
        SingleLang("PMScans", "https://rackusreads.com", "en"),
        SingleLang("Pojok Manga", "https://pojokmanga.net", "id", overrideVersionCode = 5),
        SingleLang("PoManga", "https://pomanga.com", "en"),
        SingleLang("Pony Manga", "https://ponymanga.com", "en", isNsfw = true),
        SingleLang("PornComix", "https://www.porncomixonline.net", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Pornhwa18", "https://pornhwa18.com", "id", isNsfw = true),
        SingleLang("Pornwha", "https://pornwha.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Portal Yaoi", "https://portalyaoi.com", "pt-BR", isNsfw = true),
        SingleLang("Prisma Hentais", "https://prismahentai.com", "pt-BR", isNsfw = true),
        SingleLang("Ragnarok Scanlation", "https://ragnarokscanlation.net", "es", overrideVersionCode = 1),
        SingleLang("RagnarokScan", "https://ragnarokscan.com", "es", overrideVersionCode = 1),
        SingleLang("Raijin Scans", "https://raijinscans.fr", "fr"),
        SingleLang("Rainbow Fairy Scan", "https://rainbowfairyscan.com", "pt-BR"),
        SingleLang("RawDEX", "https://rawdex.net", "ko", isNsfw = true, overrideVersionCode = 1),
        SingleLang("ReadAdult", "https://readadult.net", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("ReaderGen", "https://fr.readergen.fr", "fr"),
        SingleLang("ReadFreeComics", "https://readfreecomics.com", "en"),
        SingleLang("ReadMangaFree", "https://readmangafree.net", "en", isNsfw = true),
        SingleLang("ReadManhua", "https://readmanhua.net", "en", overrideVersionCode = 2),
        SingleLang("Reaper Scans", "https://reaperscans.fr", "fr"),
        SingleLang("Reset Scans", "https://reset-scans.us", "en"),
        SingleLang("Rh2PlusManga", "https://www.rh2plusmanga.com", "th", isNsfw = true, overrideVersionCode = 5),
        SingleLang("RichtoScan", "https://richtoscan.com", "es"),
        SingleLang("Rightdark Scan", "https://rightdark-scan.com", "es"),
        SingleLang("Rio2 Manga", "https://rio2manga.net", "en", overrideVersionCode = 1),
        SingleLang("ROG Mangás", "https://rogmangas.com", "pt-BR", pkgName = "mangasoverall", className = "RogMangas", overrideVersionCode = 1),
        SingleLang("Romantik Manga", "https://romantikmanga.com", "tr"),
        SingleLang("Rüya Manga", "https://www.ruyamanga.com", "tr", className = "RuyaManga", overrideVersionCode = 1),
        SingleLang("S2Manga", "https://www.s2manga.com", "en", overrideVersionCode = 2),
        SingleLang("Sagrado Império da Britannia", "https://imperiodabritannia.com", "pt-BR", className = "ImperioDaBritannia"),
        SingleLang("SamuraiScan", "https://samuraiscan.com", "es", overrideVersionCode = 3),
        SingleLang("Sawamics", "https://sawamics.com", "en"),
        SingleLang("ScamberTraslator", "https://scambertraslator.com", "es", overrideVersionCode = 3),
        SingleLang("Scan Hentai Menu", "https://scan.hentai.menu", "fr", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Scantrad-VF", "https://scantrad-vf.co", "fr", className = "ScantradVF"),
        SingleLang("Sdl scans", "https://sdlscans.com", "es", className = "SdlScans"),
        SingleLang("Setsu Scans", "https://setsuscans.com", "en", overrideVersionCode = 2),
        SingleLang("Shadowtrad", "https://shadowtrad.net", "fr"),
        SingleLang("ShavelProiection", "https://www.shavelproiection.com", "it", true),
        SingleLang("Shayami", "https://shayami.com", "es"),
        SingleLang("Shiba Manga", "https://shibamanga.com", "en"),
        SingleLang("Shield Manga", "https://shieldmanga.io", "en", overrideVersionCode = 3),
        SingleLang("Shinigami", "https://shinigamitoon.com", "id", overrideVersionCode = 16),
        SingleLang("Shooting Star Scans", "https://shootingstarscans.com", "en"),
        SingleLang("ShoujoHearts", "https://shoujohearts.com", "en", overrideVersionCode = 2),
        SingleLang("Sinensis Scan", "https://sinensisscan.net", "pt-BR", pkgName = "sinensis", overrideVersionCode = 6),
        SingleLang("SISI GELAP", "https://sigel.asia", "id", overrideVersionCode = 4),
        SingleLang("SkyManga.xyz", "https://skymanga.xyz", "en", isNsfw = true, className = "SkyMangaXyz"),
        SingleLang("Sleepy Translations", "https://sleepytranslations.com", "en", overrideVersionCode = 1),
        SingleLang("Solo Leveling", "https://readsololeveling.online", "en"),
        SingleLang("Sugar Babies", "https://sugarbbscan.com", "en", overrideVersionCode = 2),
        SingleLang("Summanga", "https://summanga.com", "en", isNsfw = true),
        SingleLang("Sunshine Butterfly Scans", "https://sunshinebutterflyscan.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Sweet Time Scan", "https://sweetscan.net", "pt-BR", overrideVersionCode = 2),
        SingleLang("Tankou Hentai", "https://tankouhentai.com", "pt-BR", isNsfw = true),
        SingleLang("TappyToon.Net", "https://tappytoon.net", "en", className = "Tappytoonnet"),
        SingleLang("Tatakae Scan", "https://tatakaescan.com", "pt-BR", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Taurus Fansub", "https://taurusmanga.com", "es", overrideVersionCode = 1),
        SingleLang("TeenManhua", "https://teenmanhua.com", "en", overrideVersionCode = 1),
        SingleLang("TenkaiScan", "https://tenkaiscan.net", "es", isNsfw = true),
        SingleLang("The Beginning After The End", "https://www.thebeginningaftertheend.fr", "fr", overrideVersionCode = 1),
        SingleLang("The Blank Scanlation", "https://theblank.net", "en", className = "TheBlank", isNsfw = true),
        SingleLang("The Guild", "https://theguildscans.com", "en"),
        SingleLang("Time Naight", "https://timenaight.com", "tr"),
        SingleLang("Todaymic", "https://todaymic.com", "en", overrideVersionCode = 1),
        SingleLang("TonizuToon", "https://tonizu.com", "tr", isNsfw = true, overrideVersionCode = 1),
        SingleLang("ToonChill", "https://toonchill.com", "en", overrideVersionCode = 1),
        SingleLang("ToonGod", "https://www.toongod.org", "en", isNsfw = true, overrideVersionCode = 5),
        SingleLang("Toonily", "https://toonily.com", "en", isNsfw = true, overrideVersionCode = 11),
        SingleLang("Toonizy", "https://toonizy.com", "en", isNsfw = true),
        SingleLang("ToonMany", "https://toonmany.com", "en", isNsfw = true),
        SingleLang("Top Manhua", "https://topmanhua.com", "en", overrideVersionCode = 3),
        SingleLang("TopReadManhwa", "https://topreadmanhwa.com", "en", isNsfw = true),
        SingleLang("Tortuga Ceviri", "https://tortuga-ceviri.com", "tr"),
        SingleLang("Traducciones Moonlight", "https://traduccionesmoonlight.com", "es"),
        SingleLang("TreeManga", "https://treemanga.com", "en", overrideVersionCode = 1),
        SingleLang("TritiniaScans", "https://tritinia.org", "en", overrideVersionCode = 4),
        SingleLang("Tumangaonline.site", "https://tumangaonline.site", "es", isNsfw = true, className = "TumangaonlineSite"),
        SingleLang("Unitoon Oficial", "https://unitoonoficial.com", "es"),
        SingleLang("Unitoon", "https://lectorunitoon.com", "es"),
        SingleLang("Valkyrie Scan", "https://valkyriescan.com", "pt-BR", isNsfw = true),
        SingleLang("Ver Manhwas", "https://vermanhwa.es", "es", isNsfw = true, overrideVersionCode = 1),
        SingleLang("VinManga", "https://vinload.com", "en", isNsfw = true),
        SingleLang("Wakamics", "https://wakamics.net", "en"),
        SingleLang("Webdex Scans", "https://webdexscans.com", "en"),
        SingleLang("Webtoon City", "https://webtooncity.com", "en"),
        SingleLang("Webtoon Hatti", "https://webtoonhatti.net", "tr", overrideVersionCode = 2),
        SingleLang("Webtoon TR", "https://webtoontr.net", "tr", isNsfw = true, overrideVersionCode = 2),
        SingleLang("WebToonily", "https://webtoonily.com", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("WebtoonScan", "https://webtoonscan.com", "en", isNsfw = true),
        SingleLang("WebtoonsTOP", "https://webtoons.top", "en", isNsfw = true),
        SingleLang("WebtoonUK", "https://webtoon.uk", "en", overrideVersionCode = 2),
        SingleLang("WebtoonXYZ", "https://www.webtoon.xyz", "en", isNsfw = true, overrideVersionCode = 3),
        SingleLang("Whale Manga", "https://whalemanga.com", "en", isNsfw = true),
        SingleLang("Winter Scan", "https://winterscan.com", "pt-BR", overrideVersionCode = 4),
        SingleLang("Wonderland Scan", "https://wonderlandscan.com", "pt-BR", overrideVersionCode = 3),
        SingleLang("WoopRead", "https://woopread.com", "en", overrideVersionCode = 1),
        SingleLang("WorldManhwas", "https://worldmanhwas.zone", "id", isNsfw = true, overrideVersionCode = 3),
        SingleLang("WuxiaWorld", "https://wuxiaworld.site", "en", overrideVersionCode = 1),
        SingleLang("YANP Fansub", "https://yanpfansub.com", "pt-BR", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Yaoi Comics", "https://ycscan.com", "pt-BR", isNsfw = true),
        SingleLang("Yaoi Hentai", "https://yaoihentai.me", "en", isNsfw = true),
        SingleLang("Yaoi.mobi", "https://yaoi.mobi", "en", isNsfw = true, className = "YaoiManga", overrideVersionCode = 4),
        SingleLang("YaoiScan", "https://yaoiscan.com", "en", isNsfw = true),
        SingleLang("YaoiToon", "https://yaoitoon.com", "en", isNsfw = true),
        SingleLang("YonaBar", "https://yonabar.com", "ar", isNsfw = true, overrideVersionCode = 2),
        SingleLang("Yuri Verso", "https://yuri.live", "pt-BR", overrideVersionCode = 3),
        SingleLang("Zandy no Fansub", "https://zandynofansub.aishiteru.org", "en"),
        SingleLang("ZinChanManga", "https://zinchanmanga.net", "en", isNsfw = true, overrideVersionCode = 1),
        SingleLang("Zinmanga", "https://zinmanga.com", "en", overrideVersionCode = 1),
        SingleLang("ZinManga.top (unoriginal)", "https://zinmanga.top", "en", className = "ZinMangaTop"),
        SingleLang("Zinmanhwa", "https://zinmanhwa.com", "en"),
        SingleLang("ZuttoManga", "https://zuttomanga.com", "en", overrideVersionCode = 1),
        SingleLang("Çizgi Roman Arşivi", "https://cizgiromanarsivi.com", "tr", className = "CizgiRomanArsivi"),
        SingleLang("Detective Conan Ar", "https://manga.detectiveconanar.com", "ar", sourceName = "شبكة كونان العربية", overrideVersionCode = 2),
        SingleLang("Arab Toons", "https://arabtoons.net", "ar", isNsfw = true, sourceName = "عرب تونز"),
        SingleLang("Comic Arab", "https://comicarab.com", "ar", isNsfw = true, sourceName = "كوميك العرب"),
        SingleLang("3asq", "https://3asq.org", "ar", className = "Manga3asq", sourceName = "مانجا العاشق", overrideVersionCode = 2),
        SingleLang("Mangalek", "https://manga-lek.net", "ar", sourceName = "مانجا ليك", overrideVersionCode = 4),
    )

    companion object {
        @JvmStatic
        fun main(args: Array<String>) {
            MadaraGenerator().createAll()
        }
    }
}
